@@ -113,18 +113,30 @@ def blueprint_factory(config: Config):
                 ] = f"{method.lower()}~{route_name}"
                 operation._default["summary"] = clean_route_name(route_name)
 
-                # TODO: solve for this
-                # for _parameter in route_parameters:
-                #     if any(
-                #         (
-                #             param.fields["name"] == _parameter.name
-                #             for param in operation.parameters
-                #         )
-                #     ):
-                #         continue
-                #     operation.parameter(
-                #         _parameter.name, _parameter.cast, "path"
-                #     )
+                for _parameter in route_parameters:
+                    if any(
+                        (
+                            param.fields["name"] == _parameter.name
+                            for param in operation.parameters
+                        )
+                    ):
+                        continue
+
+                    kwargs = {}
+                    if operation._autodoc and (
+                        parameters := operation._autodoc.get("parameters")
+                    ):
+                        description = None
+                        for param in parameters:
+                            if param["name"] == _parameter.name:
+                                description = param["description"]
+                                break
+                        if description:
+                            kwargs["description"] = description
+
+                    operation.parameter(
+                        _parameter.name, _parameter.cast, "path", **kwargs
+                    )
 
                 specification.operation(uri, method, operation)
 
